@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -16,10 +16,29 @@
 */
 
 #include "othermailerutil.h"
-
+#include <KLocalizedString>
 #include <QStandardPaths>
+#include <QDir>
+
+using namespace MailImporter;
+QStringList OtherMailerUtil::isMailerFound()
+{
+    QStringList lst;
+    QDir directory(OtherMailerUtil::trojitaDefaultPath());
+    if (directory.exists()) {
+        lst << i18nc("name of trojira application", "Trojita");
+    }
+    directory = OtherMailerUtil::gearyDefaultPath();
+    if (directory.exists()) {
+        lst << i18nc("name of geary application", "Geary");
+    }
+    directory = OtherMailerUtil::nylasMailDefaultPath();
+    if (directory.exists()) {
+        lst << i18nc("name of geary application", "Geary");
+    }
+    return lst;
+}
 
-namespace MailImporter {
 QString OtherMailerUtil::trojitaDefaultPath()
 {
     const QString path = QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + QLatin1String("/flaska.net/");
@@ -31,4 +50,9 @@ QString OtherMailerUtil::gearyDefaultPath()
     const QString path = QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + QLatin1String("/geary/");
     return path;
 }
+
+QString OtherMailerUtil::nylasMailDefaultPath()
+{
+    const QString path = QDir::homePath() + QLatin1String("/.nylas-mail/");
+    return path;
 }
